import { AllColorKeyType } from '@nuskin/foundation-theme';
import { render } from '@testing-library/react';

import { HeroBannerItemProps } from '../../types/types';
import HeroBanner from './HeroBanner';

const renderComponent = (props: HeroBannerItemProps) => render(<HeroBanner heroItem={props} />);

describe('Hero - NsHeroBanner', () => {
    describe('When link is provided', () => {
        const mockCta = {
            url: 'mock url',
            text: 'mock label'
        };
        const props = {
            backgroundColor: 'transparent' as AllColorKeyType,
            callToAction: mockCta,
            image: ''
        };
        it('1. It should render the anchor', () => {
            const { getByTestId } = renderComponent(props);
            const el = getByTestId('cta');
            expect(el).toBeInTheDocument();
        });
        it('2. It should render the cta button', () => {
            const { getByTestId } = renderComponent(props);
            const el = getByTestId('cta');
            expect(el).toBeInTheDocument();
        });

        describe('But has no url', () => {
            const props = {
                backgroundColor: 'transparent' as AllColorKeyType,
                callToAction: {
                    ...mockCta,
                    url: ''
                },
                image: ''
            };
            it('3. It should not render the link', () => {
                const { queryByTestId } = renderComponent(props);
                const el = queryByTestId('cta');
                expect(el).not.toBeInTheDocument();
            });
            it('4. It should not render the button', () => {
                const { queryByTestId } = renderComponent(props);
                const el = queryByTestId('button');
                expect(el).not.toBeInTheDocument();
            });
        });

        describe('But has no label', () => {
            const props = {
                backgroundColor: 'transparent' as AllColorKeyType,
                callToAction: {
                    ...mockCta,
                    label: undefined
                },
                image: ''
            };
            it('5. It should render the link', () => {
                const { getByTestId } = renderComponent(props);
                const el = getByTestId('cta');
                expect(el).toBeInTheDocument();
            });
            it('6. It should not render the button', () => {
                const { queryByTestId } = renderComponent(props);
                const el = queryByTestId('button');
                expect(el).not.toBeInTheDocument();
            });
        });
    });
});
