import { AllColorKeyType } from '@nuskin/foundation-theme';

import { render } from '../../../../test-utils';
import { SplitBannerItemProps } from '../../types/types';
import SplitBanner from './SplitBanner';

const renderComponent = (props: SplitBannerItemProps) => render(<SplitBanner heroItem={props} />);

describe('Hero - SplitBanner', () => {
    const mockLink = {
        url: 'mock url',
        text: 'mock display name'
    };
    // links
    describe('When call to action is provided', () => {
        const props = {
            backgroundColor: 'transparent' as AllColorKeyType,
            callToAction: mockLink,
            show: true,
            image: ''
        };
        it('It shouid render the call to action', () => {
            const { getByTestId } = renderComponent(props);
            const el = getByTestId('cta');
            expect(el).toBeInTheDocument();
        });

        describe('But has no url', () => {
            const props = {
                backgroundColor: 'transparent' as AllColorKeyType,
                callToAction: {
                    ...mockLink,
                    url: undefined as any
                },
                image: '',
                show: true
            };
            it('It should not render the call to action', () => {
                const { queryByTestId } = renderComponent(props);
                const el = queryByTestId('cta');
                expect(el).not.toBeInTheDocument();
            });
        });

        describe('But has no displayName', () => {
            const props = {
                backgroundColor: 'transparent' as AllColorKeyType,
                callToAction: {
                    ...mockLink,
                    text: undefined as any
                },
                image: '',
                show: true
            };
            it('It should not render the call to action', () => {
                const { queryByTestId } = renderComponent(props);
                const el = queryByTestId('cta');
                expect(el).not.toBeInTheDocument();
            });
        });
    });
});
