import { render } from '@testing-library/react';
import { ThreeCardsProps } from '../../types/types';
import ThreeCards from './ThreeCards';
import HeroCard from './HeroCard';

const renderComponent = (props: ThreeCardsProps) =>
    render(
        <ThreeCards
            type={''}
            show={false}
            full_width={false}
            container_background_color={'A100'}
            include_gap={false}
            main_hero_card={{} as any}
            sub_hero_1={{} as any}
            sub_hero_2={{} as any}
            {...{ props }}
        />
    );

    
describe('HeroCard component', () => {
    const mockProps = {
        preHeader: 'Pre-header text',
        header: 'Header text',
        description: 'Description text',
        fontColor: '#000000',
        backgroundColor: '#ffffff',
        backgroundScrim: false,
        image: 'image-url.jpg',
        callToAction: {
            text: 'Click here',
            url: 'https://example.com',
            ctaVariant: 'primary'
        },
        renderH1: false,
        liveTags: {
            preHeader: {
                'data-custom': 'pre-header'
            },
            header: {
                'data-custom': 'header'
            },
            description: {
                'data-custom': 'description'
            },
            callToAction: {
                'data-custom': 'call-to-action'
            }
        },
        dataTestId: 'hero-card-test',
        isMain: true
    };
    
    it('renders correctly with provided props', () => {
        const { getByTestId, getByText } = render(<HeroCard {...mockProps as any} />);
            
        // Check if elements are rendered
        expect(getByTestId('hero-card-test')).toBeInTheDocument();
        expect(getByTestId('pre-header')).toHaveTextContent('Pre-header text');
        expect(getByTestId('header')).toHaveTextContent('Header text');
        expect(getByTestId('description')).toHaveTextContent('Description text');
        expect(getByText('Click here')).toBeInTheDocument();
    });
    
    // Add more test cases as needed
});

describe('Hero - ThreeCards', () => {
    describe('Default (happy path)', () => {
        const DEFAULT_PROPS = {
            cards: [
                {
                    preHeader: '',
                    image: 'mock image',
                    header: 'main header',
                    description: 'main description'
                },
                {
                    preHeader: 'sub 1 pre header',
                    image: 'mock image',
                    header: 'sub 1 header'
                },
                {
                    preHeader: 'sub 2 pre header',
                    image: 'mock image',
                    header: 'sub 2 header'
                }
            ]
        };

        [
            {
                testId: 'hero-card-0',
                childTests: ['image', 'header', 'description']
            },
            {
                testId: 'hero-card-1',
                childTests: ['image', 'header', 'preHeader']
            },
            {
                testId: 'hero-card-2',
                childTests: ['image', 'header', 'preHeader']
            }
        ].forEach(({ testId, childTests }) => {
            describe(`For ${testId}`, () => {
                it('it should render card', () => {
                    const { queryByTestId } = renderComponent(DEFAULT_PROPS as any);
                    expect(queryByTestId(testId)).toBeInTheDocument();
                });

                

                childTests.forEach((childTest) => {
                    it(`it should render card ${childTest}`, () => {
                        const { queryByTestId } = renderComponent(DEFAULT_PROPS as any);
                        expect(queryByTestId(testId)).toBeInTheDocument();
                    });
                });
            });
        });
    });
});
