import { PropsWithChildren } from 'react';

import { BodyBlockMap, GlobalFieldMap } from '../../BlocksMap';
import { RefComponentProps } from '../../../types';

export type RefParserType = {
    show: boolean;
    type: string;
    component_reference: RefComponentProps[];
};

const getBlockContentType = (block: RefComponentProps) => {
    return GlobalFieldMap[block._content_type_uid] || block._content_type_uid;
};

const getBlockData = (block: RefComponentProps) => {
    return block?.component ? block.component : block;
};

const RefComponentParser = (props: PropsWithChildren<RefParserType>) => {
    const pageBlocks = props?.component_reference?.[0];

    const contentType = getBlockContentType(pageBlocks);
    const blockData = getBlockData(pageBlocks);
    const BlockComponent = BodyBlockMap[contentType]?.component;

    if (!BlockComponent) {
        return <></>;
    }

    return <BlockComponent key={contentType} {...blockData} />;
};

export default RefComponentParser;
