import { render } from '@testing-library/react';
import { ShowcaseProps } from '../../types/types';
import { SHOWCASE_DEFAULT } from '../fixtures/Showcase';
import Showcase from './Showcase';

const renderComponent = (props: ShowcaseProps) => render(<Showcase {...props} />);

describe('Ns Showcase - Showcase (default)', () => {
    beforeAll(() => {
        console.error = () => '';
    });
    describe('Default positive test', () => {
        const positiveTests = [
            'pre-header',
            'header',
            'description',
            'test-bynder-image',
            'ctaLink-component'
        ];

        positiveTests.forEach((testId, index) => {
            it(`${index}. Should render the ${testId}`, () => {
                const { queryByTestId } = renderComponent(SHOWCASE_DEFAULT);
                const el = queryByTestId(testId);
                expect(el).toBeInTheDocument();
            });
        });

        it('6. Should render two accent images', () => {
            const { queryAllByTestId } = renderComponent(SHOWCASE_DEFAULT);
            const el = queryAllByTestId('accent-image');
            expect(el.length).toBe(2);
        });
    });

    describe('negative tests', () => {
        const negativeTests = [
            {
                prop: 'preHeader',
                testId: 'pre-header'
            },
            {
                prop: 'header',
                testId: 'header'
            },
            {
                prop: 'description',
                testId: 'description'
            },
            {
                prop: 'callToAction',
                testId: 'ctaLink-component'
            }
        ];
        negativeTests.forEach(({ prop, testId }, index) => {
            it(`${index}. Given without ${prop} Should not render the ${prop}`, () => {
                const { queryByTestId } = renderComponent({
                    ...SHOWCASE_DEFAULT,
                    [prop]: undefined
                });
                const el = queryByTestId(testId);
                expect(el).not.toBeInTheDocument();
            });
        });
    });
    const ctaNegativeTests = ['url', 'text'];

    ctaNegativeTests.forEach((prop, index) => {
        it(`${index}. [cta] Given a cta but without ${prop} Should not render the call to action`, () => {
            const callToAction = {
                url: 'mock cta url',
                text: 'mock cta text'
            };

            const { queryByTestId } = renderComponent({
                ...SHOWCASE_DEFAULT,
                callToAction: {
                    ...callToAction,
                    [prop]: undefined
                }
            });
            const el = queryByTestId('ctaLink-component');
            expect(el).not.toBeInTheDocument();
        });
    });
});
