import compose from 'ramda/src/compose';
import map from 'ramda/src/map';
import propOr from 'ramda/src/propOr';

import { parseJsonString } from '../../utils';
import { VideoTypeName } from '../types/types';

enum VIDEO_PROVIDERS {
    YOUTUBE = 'youtube',
    VIMEO = 'vimeo'
}

const YOUTUBE_BASE_URL = 'https://www.youtube.com/embed/';
const VIMEO_BASE_URL = 'https://player.vimeo.com/video/';

const formatDefaultVideoModel = (item: any, tag?: string) => {
    const href =
        (item.videoSource === VIDEO_PROVIDERS.VIMEO ? VIMEO_BASE_URL : YOUTUBE_BASE_URL) +
        item?.url;
    return {
        allowFullScreen: propOr(false, VideoTypeName.allowFullScreen)(item),
        type: propOr('default', VideoTypeName.videoSource)(item),
        href,
        liveTag: tag
    };
};

const getDefaultVideoModel = (item: any) => {
    const name = Object.keys(item)?.[0];
    const values = Object.values(item)?.[0];
    if (values) {
        if (name === VideoTypeName.default) {
            return formatDefaultVideoModel(
                parseJsonString(item[VideoTypeName.default]?.[VideoTypeName.defaultVideo]),
                item?.$?.[VideoTypeName.default]
            );
        }
    }
    return {};
};

export const getDefaultVideoData = compose(map(getDefaultVideoModel), propOr({}, 'video'));
